<TeXmacs|1.0.7.3>

<style|<tuple|article|maxima>>

<\body>
  <doc-data|<doc-title|Manual of SARAG<next-line>(Some Algorithms
  in<next-line>Real Algebraic Geometry)>>

  \;

  SARAG was developed by Fabrizio Caruso under the scientific guidance of
  Marie-Franoise Roy at the University of Rennes 1, France, with support
  from the RAAG network, further developed at the University of Pisa, Italy,
  modified by Alexandre Le Meur and Marie-Franoise Roy at the University of
  Rennes 1. This manual has been written by Alexandre Le Meur.

  Please report bugs to: fabrizio.caruso@posso.dm.unipi.it or
  marie-francoise.roy@univ-rennes1.fr

  Also part of the free interactive book "Algorithms in Real Algebraic
  Geometry" by Saugata Basu, Richard Pollack, Marie-Franoise Roy
  Springer-Verlag, Berlin, 2003 (second edition 2006) which together with
  SARAG is available for download at http://name.math.univ-rennes1.fr/marie-francoise.roy/bpr-posted2.html

  <section|Introduction>

  <subsection|The SARAG Library>

  Free open source Maxima library for some algorithms of real algebraic
  geometry.

  SARAG provides functions for linear algebra, theory of subresultants,
  Cauchy Index and its application to real root counting, isolation of real
  roots, sign determination, Thom encodings as well as certificates of
  positivity in the univariate case.

  <subsection|Requirements>

  <\itemize-minus>
    <item>MAXIMA (5.9.2 or above) The library has been initially developed
    and tested with Maxima version 5.9.2 and 5.9.3. SARAG with the only
    exception of plotting (e.g., "drawTopology") also works on Maxima 5.9.1.
    The latest version of Maxima tested so far is Maxima 5.20.1. The latest
    version of Maxima is available on line at http://maxima.sourceforge.net/.\ 

    <item>GNUPLOT (3.7.x, 4.0.x or above) The library uses Gnuplot for
    plotting graphs and it has been tested successfully on Gnuplot 3.7.x and
    4.0.x.
  </itemize-minus>

  It is also useful to install <TeXmacs> which has a Maxima plugin, if you
  want to use this manual interactively for example (using saragmanual.tm
  rather than saragmanual.pdf).

  <subsection|Loading the files>

  You can work directly in Maxima, or use the Maxima plugin inside <TeXmacs>
  (which is done in the examples given in this manual).

  \;

  file : sarag.mac

  The library is contained in the following files:

  sarag.mac (it loads all the files, settings.mac (general settings),
  constants.mac, sarag_initialization.mac ,aliases.mac (name conventions),
  lowLevel.mac (low level routines), sarag_linear_algebra.mac (linear algebra
  and matrix manipulation) ,rootCounting.mac (real root counting),
  rootIsolation.mac (root isolation by De Casteljau method),
  signDetermination.mac (sign determination), intervalArithmetic.mac
  (interval arithmetic), topology.mac (topology of curves),
  certificatesOfPositivity (certificates of positivity in the univariate
  case), multiCertificatesOfPositivity (certificates of positivity in the
  multivaritate case), arag_test.mac (test file for the book "Algorithms in
  Real Algebrain Geometry") hard_test.mac (test files with mostly topology
  computations), saragmanuel.tm and saragmanual.pdf (this manual).

  \;

  ATTENTION:The variables of the different functions are explicited in the
  file named \S variables \T.

  \;

  In order to load the library either load the file "sarag.mac" that will
  load all the files if they are in the same directory indicated by
  <with|color|red|path> : load("<with|color|red|path>/sarag.mac") or load
  each single file with the "load" Maxima command.

  Example: if the library is contained in a folder named SARAG in the
  directory where you are working type\ 

  load("./SARAG/sarag.mac");

  <\unfolded>
    Load the library
  <|unfolded>
    <\session|maxima|default>
      <\unfolded-io>
        <with|color|red|(<with|math-font-family|rm|%i>1) <with|color|black|>>
      <|unfolded-io>
        load("./SARAG/sarag.mac");
      <|unfolded-io>
        <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o1>)
        <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
      </unfolded-io>
    </session>
  </unfolded>

  \;

  In order to test the library you can use:

  batch("<with|color|red|path>/arag_test.mac",test);\ 

  and

  batch("<with|color|red|path>/hard_test.mac",test);

  <with|color|red|path> must be replace by the path of the folder containing
  the library :

  exemple :

  batch("./SARAG/arag_test.mac",test)

  batch("./SARAG/hard_test.mac",test);

  If there are errors they are reported in arag_test.ERR and hard_test.ERR.
  Dont pay attention to the output you get in Maxima, just open these files.

  <\unfolded>
    Test the library
  <|unfolded>
    <\session|maxima|default>
      \;

      <\unfolded-io>
        <with|color|red|(<with|math-font-family|rm|%i>2) <with|color|black|>>
      <|unfolded-io>
        load("./SARAG/sarag.mac");
      <|unfolded-io>
        <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o2>)
        <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
      </unfolded-io>

      <\unfolded-io>
        <with|color|red|(<with|math-font-family|rm|%i>3) <with|color|black|>>
      <|unfolded-io>
        batch("./SARAG/arag_test.mac",test);
      <|unfolded-io>
        \;
      </unfolded-io>

      <\unfolded-io>
        <with|color|red|(<with|math-font-family|rm|%i>3) <with|color|black|>>
      <|unfolded-io>
        batch("./SARAG/hard_test.mac",test);
      <|unfolded-io>
        \;
      </unfolded-io>

      <\input>
        <with|color|red|(<with|math-font-family|rm|%i>2) <with|color|black|>>
      <|input>
        \;
      </input>
    </session>
  </unfolded>

  <subsection|Manual>

  file : manual.tm and manual.pdf

  This manual describes the high level functions ("main functions") of the
  SARAG library and the most important auxiliary functions.

  The file manual.tm is a <TeXmacs> file in which you can work interactively
  using Maxima plugin.

  For more details and for the theory behind the algorithms we refer to
  "Algorithms in Real Algebraic Geometry" by S. Basu, R. Pollack, M.-F. Roy
  which together with SARAG is available for download at
  http://name.math.univ-rennes1.fr/marie-francoise.roy/bpr-posted1.html and,
  for certificate of positivity, to F. Boudaoud, F. Caruso M.-F. Roy
  Certificates of positivity in the Bernstein basis, Discrete and
  Computational Geometry 39 4 639-655 (2008)

  <subsection|Naming conventions>

  file : aliases.mac

  The names of main functions are formed by adding prefixes to specify the
  method/algorithm which is used and suffixes to specify an alternative
  version of the function or output.\ 

  When no prefix or no suffix is used the function with the default
  method/algorithm will be called as set in the file: "aliases.mac".

  Auxiliary functions may not follow such conventions.

  <subsection|Form of the output>

  The output of all functions of the library is a Maxima expression. Maxima
  uses brakets "[", "]" to describe couples and lists (e.g. an open inteval
  (a,b) is described by a couple containing the ends, which in Maxima is
  "[a,b]")

  <section|Functions and syntax>

  In this Section, all functions are described, with \ syntax and arguments.
  For each function we use an example to show how the function works and what
  it returns. The code of each function can be found in the corresponding
  file. Moreover, a maxima window untitled \S use it yourself \T is
  \ provided to test functions with your own examples.

  For several functions the library provides different methods for computing
  the result. This is indicated in the syntax part of a descrition in the
  paragraph Method. The default method, sert is aliases.mac is indicated with
  a *. Methods \ not implemented yet are indicated in <with|color|grey|grey>.

  <subsection|Linear algebra>

  The corresponding results are explained in "Algorithms in Real Algebraic
  Geometry" by S. Basu, R. Pollack, M.-F. Roy, mainly in Chapter 8.

  <em|file : sarag_linear_algebra.mac>

  This file contains functions related to Gaussian elimination and matrix
  manipulations (products, determinant, etc.)

  \;

  <subsubsection|Matrix product>

  <\detailed>
    <render-proof|Matrix Product|Computes the product of two matrices>
  <|detailed>
    <\render-proof|Matrix Product:>
      Computes the product of two matrices\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : matrixProd(A,B)

        Input : A and B are lists of lists representing the rows of two
        matrices such that A has the same number of columns as B as rows

        Output : the row-column product matrix of A, B
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\inactive>
          <\session|maxima|default>
            <\unfolded-io>
              <with|color|red|(<with|math-font-family|rm|%i>3)
              <with|color|black|>>
            <|unfolded-io>
              load("./SARAG/sarag.mac");
            <|unfolded-io>
              <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o6>)
              <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
            </unfolded-io>

            <\unfolded-io>
              <with|color|red|(<with|math-font-family|rm|%i>7)
              <with|color|black|>>
            <|unfolded-io>
              matrixProd([[1,0,1],[0,1,0],[1,1,0]],[[1,0,0],[0,1,0],[0,0,1]]);
            <|unfolded-io>
              <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o7>)
              <with|color|black|>><left|[><left|[>1,0,1<right|]>,<left|[>0,1,0<right|]>,<left|[>1,1,0<right|]><right|]>>
            </unfolded-io>

            <\input>
              <with|color|red|(<with|math-font-family|rm|%i>8)
              <with|color|black|>>
            <|input>
              \;
            </input>
          </session>
        </inactive>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/sarag_linearAlgebra.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>4)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>5)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsubsection|Determinant, elimination>

  <strong|<samp|<samp|Main Functions : >>>

  <\detailed>
    <render-proof|Determinant|Computes the determinant of a square matrix>
  <|detailed>
    <\render-proof|Determinant:>
      \ Computes the determinant of a square matrix

      <\unfolded>
        Syntax
      <|unfolded>
        Name : det(M)

        Input : M is a list of lists representing the rows of a matrix

        Method :\ 

        <\itemize-dot>
          <item>Gauss [Gaussian elimination with no pivot optimization]

          <item>Bareiss [Bareiss method]*
        </itemize-dot>

        Output : the determinant of M
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>8)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o8>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>9)
            <with|color|black|>>
          <|unfolded-io>
            det([[1,0,0],[0,1,0],[0,0,1]]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o9>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>10)
            <with|color|black|>>
          <|unfolded-io>
            gaussDet([[1,0,0],[0,1,0],[0,0,1]]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o10>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>11)
            <with|color|black|>>
          <|unfolded-io>
            bareissDet([[1,0,0],[0,1,0],[0,0,1]]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o11>)
            <with|color|black|>>1>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>12)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/sarag_linearAlgebra.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>19)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o19>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Elimination|Computes the upper triangular equivalent form
    of a matrix>
  <|detailed>
    <\render-proof|Elimination:>
      \ Computes the upper triangular equivalent form of a matrix

      <\unfolded>
        Syntax
      <|unfolded>
        Name : elim(M)

        Input : M is a list of lists representing the rows of a matrix

        Method :\ 

        <\itemize-dot>
          <item>Gauss [Gaussian elimination with no pivot optimization]

          <item><with|color|grey|Bareiss [Bareiss method]>
        </itemize-dot>

        Output : [t,c,z] where :\ 

        <\enumerate-roman>
          <item>t is an upper triangular equivalent form of M with possibly
          some zero rows computed by Gaussian elimination with divisions and
          columns exchanges

          <item>c is the list of couples describing the columns exchanges

          <item>z is the list of zero rows
        </enumerate-roman>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>2)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o2>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>7)
            <with|color|black|>>
          <|unfolded-io>
            elim([[0,1,0],[0,0,1],[1,0,0]]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o7>)
            <with|color|black|>><left|[><left|[><left|[>1,0,0<right|]>,<left|[>0,1,0<right|]>,<left|[>0,0,1<right|]><right|]>,<left|[><left|[>0,1<right|]>,<left|[>1,2<right|]><right|]>,<left|[><right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>8)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/sarag_linearAlgebra.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>2)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o2>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>3)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsubsection|Characteristic polynomial>

  <samp|<strong|<samp|<strong|Auxiliary Functions :
  ><samp|>><strong|<verbatim|<em|<em|>>>>>>

  <\detailed>
    <render-proof|Polynomial From Newton|Computes the polynomial
    corresponding to given Newton Sums>
  <|detailed>
    <\render-proof|Polynomial From Newton :>
      \ Computes the polynomial corresponding to given Newton Sums

      <\unfolded>
        Syntax
      <|unfolded>
        Name : polyFromNewton(ns,var)\ 

        Input : ns is a list containing the Newton sums of a given polynomial
        in variable var

        Output : the corresponding polynomial
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>5)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o5>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>13)
            <with|color|black|>>
          <|unfolded-io>
            polyFromNewton([3,0,2,0],x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o13>)
            <with|color|black|>>x<rsup|3>-x>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>14)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/sarag_linearAlgebra.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Newton From Polynomial|Computes the Newton Sums
    corresponding to a given Polynomial.>
  <|detailed>
    <\render-proof|Newton From Polynomial :>
      \ Computes the Newton Sums corresponding to a given Polynomial.

      <\unfolded>
        Syntax
      <|unfolded>
        Name : newtonFromPoly(P,var,len)

        Input : P is a polynomial in variable var, len is a non negative
        integer

        Output : array containing the n+1 newton sums of P
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>16)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o16>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>17)
            <with|color|black|>>
          <|unfolded-io>
            newtonFromPoly(x^3-x,x,3);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o17>)
            <with|color|black|>><left|[>3,0,2,0<right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>18)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/sarag_linearAlgebra.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <strong|<samp|<samp|Main Functions : >>>

  <\detailed>
    <render-proof|Characteristic Polynomial|Computes the characteristic
    polynomial of a square matrix>
  <|detailed>
    <\render-proof|Characteristic Polynomial:>
      \ Computes the characteristic polynomial of a square matrix

      <\unfolded>
        Syntax
      <|unfolded>
        Name : charPol(A,var)

        Input : A is a list of lists representing the rows of a matrix

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomial (for
        example x)

        Method :\ 

        <\itemize-dot>
          <item>Gauss [Gaussian elimination with no pivot optimization]

          <item><with|color|grey|Bareiss [Bareiss method]>

          <item>Baby Giant [baby step, giant step trace-based method]*
        </itemize-dot>

        Output : the characteristic polynomial of A in the indeterminate var
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>12)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o12>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>13)
            <with|color|black|>>
          <|unfolded-io>
            charPol([[1,2,3,4], [2,3,4,5], [3,4,5,6], [5,6,7,8]],x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o13>)
            <with|color|black|>>x<rsup|4>-17*x<rsup|3>-26*x<rsup|2>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>14)
            <with|color|black|>>
          <|unfolded-io>
            babyGiantCharPol([[1,2,3,4], [2,3,4,5], [3,4,5,6], [5,6,7,8]],x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o14>)
            <with|color|black|>>x<rsup|4>-17*x<rsup|3>-26*x<rsup|2>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>15)
            <with|color|black|>>
          <|unfolded-io>
            gaussCharPol([[1,2,3,4], [2,3,4,5], [3,4,5,6], [5,6,7,8]],x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o15>)
            <with|color|black|>>x<rsup|4>-17*x<rsup|3>-26*x<rsup|2>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>16)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/sarag_linearAlgebra.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Descartes Signature|Computes the signature of a symmetric
    matrix by the Descartes' Rule applied to the characteristic polynomial>
  <|detailed>
    <\render-proof|Descartes Signature:>
      \ Computes the signature of a symmetric matrix by the Descartes' Rule
      applied to the characteristic polynomial

      <\unfolded>
        Syntax
      <|unfolded>
        Name : descartesSignature(M)

        Input : M is a list of lists representing a square symmetric matrix

        Output : the signature of M
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>33)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o33>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>34)
            <with|color|black|>>
          <|unfolded-io>
            descartesSignature([[1,0,0],[0,1,0],[0,0,1]]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o34>)
            <with|color|black|>>3>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>35)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/sarag_linearAlgebra.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsection|Root counting>

  <samp|><em|file : rootCounting.mac>

  <subsubsection|Signes changes>

  The corresponding results are explained in "Algorithms in Real Algebraic
  Geometry" by S. Basu, R. Pollack, M.-F. Roy, mainly in Chapter 2 and 9.

  <\detailed>
    <render-proof|Sign Changes|Counts the number of sign changes in a
    sequence of real numbers>
  <|detailed>
    <\render-proof|Sign Changes:>
      \ Counts the number of sign changes in a sequence of real numbers

      <\unfolded>
        Syntax
      <|unfolded>
        Name : signChanges(seq)

        Input : seq is a sequence of number

        Output : number of sign changes in the sequence
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>35)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o35>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>36)
            <with|color|black|>>
          <|unfolded-io>
            signChanges([1,0,0,1,2,3,-8,0,1]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o36>)
            <with|color|black|>>2>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>37)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Modified Sign Changes|Slight modification of the number of
    sign changes \ in a sequence of real numbers taking into account existing
    zeroes in the sequence.>
  <|detailed>
    <\render-proof|Modified Sign Changes:>
      \ Slight modification of the number of sign changes \ in a sequence of
      real numbers taking into account existing zeroes in the sequence.

      <\unfolded>
        Syntax
      <|unfolded>
        Name : modifiedSignChanges(seq)

        Input : seq is a sequence of number

        Output : number of sign changes in the sequence. Warning! Annulations
        count for a sign change!
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>41)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o41>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>42)
            <with|color|black|>>
          <|unfolded-io>
            modifiedSignChanges([1,0,0,1,2,3,-8,0,1]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o42>)
            <with|color|black|>>4>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>43)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Generalized Permancences Minus Variations|Computes a
    generalization of the difference between Permanences and Variations of a
    sequence>
  <|detailed>
    <\render-proof|Generalized Permancences Minus Variations:>
      \ Computes a generalization of the difference between Permanences and
      Variations of a sequence

      <\unfolded>
        Syntax
      <|unfolded>
        Name: genPermMVar(seq)

        Input: seq a sequence of elements in an ordered integral domain

        Output: PmV(seq)
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>6)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o6>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>23)
            <with|color|black|>>
          <|unfolded-io>
            genPermMVar([1,0,0,1,2,3,-8,0,1]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o23>)
            <with|color|black|>>0>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>24)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsubsection|Signed remainder sequence>

  The corresponding results are explained in "Algorithms in Real Algebraic
  Geometry" by S. Basu, R. Pollack, M.-F. Roy, mainly in Chapter 2 and 8.

  <\detailed>
    <render-proof|Signed Remainder Sequence|Computes the signed remainder
    sequence of two polynomials>
  <|detailed>
    <\render-proof|Signed Remainder Sequence:>
      Computes the signed remainder sequence of two polynomials

      <\unfolded>
        Syntax
      <|unfolded>
        Name : sRem(P,Q,var)

        Input : P and Q are polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        \;

        Output : list containing signed remainder sequence
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>37)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o37>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>38)
            <with|color|black|>>
          <|unfolded-io>
            sRem(x^11-x^10+1,11*x^10-10*x^9,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o38>)
            <with|color|black|>><left|[>x<rsup|11>-x<rsup|10>+1,11*x<rsup|10>-10*x<rsup|9>,<frac|10*x<rsup|9>-121|121>,-<frac|1331*x-1210|10>,<frac|275311670611|285311670611><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>39)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Extended Signed Remainder Sequence|Same as previous
    function but include also the corresponding sequence of cofactors>
  <|detailed>
    <\render-proof|Extended Signed Remainder Sequence:>
      Same as previous function but include also the corresponding sequence
      of cofactors\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : sRemExt(P,Q,var)

        Input : P and Q are polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        \;

        Output : [r,u,v] forming the extended signed remainder sequence where
        r is the signed remainder sequence and u and v are the corresponding
        sequences of cofactors
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>39)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o39>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>40)
            <with|color|black|>>
          <|unfolded-io>
            sRemExt(x^3+2*x^2+3*x+4,3*x^2+4*x+3,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o40>)
            <with|color|black|>><left|[><left|[>x<rsup|3>+2*x<rsup|2>+3*x+4,3*x<rsup|2>+4*x+3,-<frac|10*x+30|9>,-18<right|]>,<left|[>1,0,-1,<frac|27*x|10>-<frac|9|2><right|]>,<left|[>0,1,<frac|x|3>+<frac|2|9>,<frac|9*x|10>-<frac|9*x<rsup|2>|10><right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>41)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsubsection|Subresultants>

  The corresponding results are explained in "Algorithms in Real Algebraic
  Geometry" by S. Basu, R. Pollack, M.-F. Roy, mainly in Chapter 4 and 8.

  <\detailed>
    <render-proof|Signed Subresultant Polynomials|Computes the list of the
    signed subresultant \ polynomials of two polynomials>
  <|detailed>
    <\render-proof|Signed Subresultant Polynomials:>
      \ Computes the list of the signed subresultant \ polynomials of two
      polynomials

      <\unfolded>
        Syntax
      <|unfolded>
        Name : sSubResPol(P,Q,var)

        Input : P and Q are polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        \;

        Output : [sSubRes] where sSubRes is a list containing the signed
        subresultant sequence

        <\enumerate-numeric>
          \;
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>43)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o43>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>44)
            <with|color|black|>>
          <|unfolded-io>
            sSubResPol(x^4+a*x^2+b*x+c, diff(x^4+a*x^2+b*x+c,x),x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o44>)
            <with|color|black|>><left|[>x<rsup|4>+a*x<rsup|2>+b*x+c,4*x<rsup|3>+2*a*x+b,-8*a*x<rsup|2>-12*b*x-16*c,32*a*c*x-36*b<rsup|2>*x-8*a<rsup|3>*x-48*b*c-4*a<rsup|2>*b,256*c<rsup|3>-128*a<rsup|2>*c<rsup|2>+144*a*b<rsup|2>*c+16*a<rsup|4>*c-27*b<rsup|4>-4*a<rsup|3>*b<rsup|2><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>45)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Sturm Sequence|Computes the Sturm sequence of a polynomial
    >
  <|detailed>
    <\render-proof|Sturm Sequence:>
      \ Computes the Sturm sequence of a polynomial\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : sturmSequence(P,var)

        Input : P polynomial

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomial (for
        example x)

        Output : the Sturm sequence of P (signed remainder sequence of P and
        its derivative)
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>73)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o73>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>74)
            <with|color|black|>>
          <|unfolded-io>
            sturmSequence(x^4+x+2,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o74>)
            <with|color|black|>><left|[>x<rsup|4>+x+2,4*x<rsup|3>+1,-<frac|3*x+8|4>,<frac|2021|27><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>75)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <\render-proof|Signed Subresultant Coefficients>
      Computes the signed subresultant coefficients of two polynomials
    </render-proof>
  <|detailed>
    <\render-proof|Signed Subresultant Coefficients>
      Computes the signed subresultant coefficients of two polynomials

      <\unfolded>
        Syntax
      <|unfolded>
        Name : sSubResCoeff(P,Q,var)

        Input : P is a polynomial in variable var

        Output : the coeffs of subdiscriminant of the polynomials P and Q
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>49)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o49>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>52)
            <with|color|black|>>
          <|unfolded-io>
            sSubResCoeff(x^3+a*x+b,diff(x^3+a*x+b,x),x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o52>)
            <with|color|black|>><left|[>1,3,-6*a,-27*b<rsup|2>-4*a<rsup|3><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>53)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Extended Signed Subresultant Sequence|Same as previous but
    includes also the corresponding sequence of cofactors>
  <|detailed>
    <\render-proof|Extended Signed Subresultant Sequence:>
      \ Same as previous but includes also the corresponding sequence of
      cofactors

      <\unfolded>
        Syntax
      <|unfolded>
        Name : sSubResExt(P,Q,var)

        Input : P and Q are polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        \;

        Output : [sSubRes, s, u, v] where

        <\enumerate-numeric>
          <item>sSubRes is a list containing the signed subresultant sequence

          <item>u, v are the corresponding cofactors
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>53)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o53>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>54)
            <with|color|black|>>
          <|unfolded-io>
            sSubResExt(x^4+b*x+c,4*x^3+b,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o54>)
            <with|color|black|>><left|[><left|[>x<rsup|4>+b*x+c,4*x<rsup|3>+b,-12*b*x-16*c,-36*b<rsup|2>*x-48*b*c,256*c<rsup|3>-27*b<rsup|4><right|]>,<left|[>1,0,-16,-48*b,144*b<rsup|2>*x<rsup|2>-192*b*c*x+256*c<rsup|2>,-1024*c<rsup|3>*x<rsup|3>+108*b<rsup|4>*x<rsup|3>-256*b*c<rsup|3>+27*b<rsup|5><right|]>,<left|[>0,1,4*x,12*b*x,-36*b<rsup|2>*x<rsup|3>+48*b*c*x<rsup|2>-64*c<rsup|2>*x-27*b<rsup|3>,256*c<rsup|3>*x<rsup|4>-27*b<rsup|4>*x<rsup|4>+256*b*c<rsup|3>*x-27*b<rsup|5>*x+256*c<rsup|4>-27*b<rsup|4>*c<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>55)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <\render-proof|GCD free part>
      Computes the GCD of two polynomials P and Q as well as P divided by
      this GCD
    </render-proof>
  <|detailed>
    <\render-proof|GCD free part>
      Computes the GCD of two polynomials P and Q as well as P divided by
      this GCD

      <\unfolded>
        Syntax
      <|unfolded>
        Name : gcdFreePart(P,Q,var)\ 

        Input : P and Q are polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        Output : [g,f] where

        <\enumerate-numeric>
          <item>g is a gcd(P,Q)

          <item>f is a gcd-free part of P with respect to Q
        </enumerate-numeric>

        Name : gcdFreePartWithZ(P,Q,var)\ 

        Input : P and Q are polynomials wiht integer coefficients

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        Output : [g,f] where

        <\enumerate-numeric>
          <item>g is a gcd(P,Q)

          <item>f is a gcd-free part of P with respect to Q
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>55)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o55>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>58)
            <with|color|black|>>
          <|unfolded-io>
            gcdFreePart((x^2-1)*(x+2),(x+1)*x,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o58>)
            <with|color|black|>><left|[>2*x+2,2*x<rsup|2>+2*x-4<right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>57)
            <with|color|black|>>
          <|unfolded-io>
            gcdFreePartWithZ((x^2-1)*(x+2),(x+1)*x,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o57>)
            <with|color|black|>><left|[>x+1,x<rsup|2>+x-2<right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>58)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <\render-proof|Sylvester Resultant>
      Computes the Sylvester Resultant of two polynomials\ 
    </render-proof>
  <|detailed>
    <\render-proof|Sylvester Resultant>
      Computes the Sylvester Resultant of two polynomials\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : sylvesterResultant(P,Q,var)

        Input : P and Q are polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        Output : the resultant of P and Q (i.e. the determinant of the
        Sylvester Matrix of P and Q)
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>59)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o59>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>61)
            <with|color|black|>>
          <|unfolded-io>
            sylvesterResultant(a*x^2+b*x+c,2*a*x+b,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o61>)
            <with|color|black|>>4*a<rsup|2>*c-a*b<rsup|2>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>62)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <\render-proof|Discriminant>
      Computes the discriminant of a polynomial
    </render-proof>
  <|detailed>
    <\render-proof|Discriminant>
      Computes the discriminant of a polynomial

      <\unfolded>
        Syntax
      <|unfolded>
        Name : discriminant(P,var)

        Input : P is a polynomial in variable var

        Output : the discriminant of the polynomial P (product of the square
        of the differences of the roots)
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>62)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o62>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>63)
            <with|color|black|>>
          <|unfolded-io>
            discriminant(x^3+p*x+q,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o63>)
            <with|color|black|>>-27*q<rsup|2>-4*p<rsup|3>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>64)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <\render-proof|Subdiscriminant>
      Computes the subdiscriminant coefficients of a polynomial
    </render-proof>
  <|detailed>
    <\render-proof|Subdiscriminant>
      Computes the subdiscriminant coefficients of a polynomial

      <\unfolded>
        Syntax
      <|unfolded>
        Name : subDiscrCoeff(P,var)

        Input : P is a polynomial in variable var

        Output : the subdiscriminans of the polynomial P
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>68)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o68>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>69)
            <with|color|black|>>
          <|unfolded-io>
            subDiscrCoeff(x^3+p*x+q,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o69>)
            <with|color|black|>><left|[>1,3,-6*p,-27*q<rsup|2>-4*p<rsup|3><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>70)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  \;

  <subsubsection|Root counting>

  The corresponding results are explained in "Algorithms in Real Algebraic
  Geometry" by S. Basu, R. Pollack, M.-F. Roy, mainly in Chapter 9.

  \;

  <em|file : rootcounting.mac>

  \ \ \ \ \ \ \ <em|rootIsolation.mac> (for De Casteljau-based's root
  counting method)

  \;

  <samp|<strong|<samp|<strong|Main Functions :
  ><samp|>><strong|<verbatim|<em|<em|>>>>>>

  <\detailed>
    <render-proof|Cauchy Index|Computes the Cauchy Index of a rational
    function>
  <|detailed>
    <\render-proof|Cauchy Index>
      \ Computes the Cauchy Index of a rational function

      <\unfolded>
        Syntax
      <|unfolded>
        Name : cauchyIndex(Q,P,var)

        Input : Q, P polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        Method :\ 

        <\enumerate-roman>
          <item>sRem [signed remainder sequence]

          <item>sSubRes [signed subresultants]*
        </enumerate-roman>

        \;

        Output : Cauchy index of Q/P in the whole real line
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>75)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o75>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>76)
            <with|color|black|>>
          <|unfolded-io>
            cauchyIndex( (x-5)*(x-4)*(x-2)*(x+1)*(x+2)*(x+4),
            (x-3)^2*(x-1)*(x+3),x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o76>)
            <with|color|black|>>0>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>78)
            <with|color|black|>>
          <|unfolded-io>
            sRemCauchyIndex( (x-5)*(x-4)*(x-2)*(x+1)*(x+2)*(x+4),
            (x-3)^2*(x-1)*(x+3),x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o78>)
            <with|color|black|>>0>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>79)
            <with|color|black|>>
          <|unfolded-io>
            sSubResCauchyIndex( (x-5)*(x-4)*(x-2)*(x+1)*(x+2)*(x+4),
            (x-3)^2*(x-1)*(x+3),x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o79>)
            <with|color|black|>>0>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>80)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Tarski Query|Computes the Tarski Query of two polynomials
    which is the difference between the number of roots of P where Q is
    positive and the number of roots of P where Q is negative>
  <|detailed>
    <\render-proof|Tarski Query>
      \ Computes the Tarski Query of two polynomials Q,P which is the
      difference between the number of roots of P where Q is positive and the
      number of roots of P where Q is negative

      <\unfolded>
        Syntax
      <|unfolded>
        Name : tarskiQuery(Q,P,var)

        Input : Q, P polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        Method :\ 

        <\enumerate-roman>
          <item>sRem [signed remainder sequence]

          <item>sSubRes [signed subresultants]*
        </enumerate-roman>

        \;

        Output : Tarski query of Q,P\ 
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>82)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o82>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>83)
            <with|color|black|>>
          <|unfolded-io>
            tarskiQuery(1,x^11-x^10+1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o83>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>84)
            <with|color|black|>>
          <|unfolded-io>
            sSubResTarskiQuery(1,x^11-x^10+1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o84>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>85)
            <with|color|black|>>
          <|unfolded-io>
            sRemTarskiQuery(1,x^11-x^10+1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o85>)
            <with|color|black|>>1>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>86)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Number of Roots|Computes the number of real roots of a
    polynomial >
  <|detailed>
    <\render-proof|Number of Roots>
      \ Computes the number of real roots of a polynomial\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : numberOfRoots(P,var)

        Input : P polynomial

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomial (for
        example x)

        Method :\ 

        <\enumerate-roman>
          <item>sRem [signed remainder sequence]

          <item>sSubRes [signed subresultants]

          <item>deCasteljau [De Casteljau method for isolation]*

          <item><with|color|grey|monomial [monomial method for isolation>]
        </enumerate-roman>

        \;

        Output : number of roots of P in the whole real line
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>86)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o86>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>89)
            <with|color|black|>>
          <|unfolded-io>
            numberOfRoots(x^2-2*x+1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o89>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>91)
            <with|color|black|>>
          <|unfolded-io>
            deCasteljauNumberOfRoots(x^2-2*x+1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o91>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>92)
            <with|color|black|>>
          <|unfolded-io>
            sRemNumberOfRoots(x^2-2*x+1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o92>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>93)
            <with|color|black|>>
          <|unfolded-io>
            sSubResNumberOfRoots(x^2-2*x+1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o93>)
            <with|color|black|>>1>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>94)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac> for sSubRes and sRem
      methods and in ./SARAG/rootIsolation.mac for Decasteljau's method>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Cauchy Index Between|Computes the Cauchy Index of a
    rational function between two real numbers>
  <|detailed>
    <\render-proof|Cauchy Index Between>
      \ Computes the Cauchy Index of a rational function between two real
      numbers

      <\unfolded>
        Syntax
      <|unfolded>
        Name : cauchyIndexBetween(Q,P,var,a,b)

        Input : Q, P polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        \ \ \ \ \ \ \ \ \ \ a and b are reals (a\<less\>b) or -INFINITY or
        +INFINITY

        Method :\ 

        <\enumerate-roman>
          <item>sRem [signed remainder sequence]

          <item>sSubRes [signed subresultants]*
        </enumerate-roman>

        \;

        Output : Cauchy index of Q/P in the interval ]a,b[
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>94)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o94>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>95)
            <with|color|black|>>
          <|unfolded-io>
            cauchyIndexBetween( (x-5)*(x-4)*(x-2)*(x+1)*(x+2)*(x+4),
            (x-3)^2*(x-1)*(x+3),x,1,-1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o95>)
            <with|color|black|>>0>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>98)
            <with|color|black|>>
          <|unfolded-io>
            sSubResCauchyIndexBetween( (x-5)*(x-4)*(x-2)*(x+1)*(x+2)*(x+4),
            (x-3)^2*(x-1)*(x+3),x,1,-1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o98>)
            <with|color|black|>>0>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>99)
            <with|color|black|>>
          <|unfolded-io>
            sRemCauchyIndexBetween( (x-5)*(x-4)*(x-2)*(x+1)*(x+2)*(x+4),
            (x-3)^2*(x-1)*(x+3),x,1,-1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o99>)
            <with|color|black|>>0>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>100)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Tarski Query Between|Computes the Tarski Query of two
    polynomials between two real numbers>
  <|detailed>
    <\render-proof|Tarski Query Between>
      Computes the Tarski Query of two polynomials between two real numbers\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : tarskiQueryBetween(Q,P,var,a,b)

        Input : Q, P polynomials

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomials (for
        example x)

        \ \ \ \ \ \ \ \ \ \ a and b are reals (a\<less\>b) or -INFINITY or
        +INFINITY

        Method :\ 

        <\enumerate-roman>
          <item>sRem [signed remainder sequence]

          <item>sSubRes [signed subresultants]*
        </enumerate-roman>

        \;

        Output : Tarski query of Q,P in ]a,b[
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>100)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o100>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>103)
            <with|color|black|>>
          <|unfolded-io>
            tarskiQueryBetween(1,x^11-x^10+1,x,0,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o103>)
            <with|color|black|>>0>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>104)
            <with|color|black|>>
          <|unfolded-io>
            sSubResTarskiQueryBetween(1,x^11-x^10+1,x,0,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o104>)
            <with|color|black|>>0>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>105)
            <with|color|black|>>
          <|unfolded-io>
            sRemTarskiQueryBetween(1,x^11-x^10+1,x,0,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o105>)
            <with|color|black|>>0>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>106)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Number of Roots Between|Computes the number of real roots
    of a polynomial between two real numbers>
  <|detailed>
    <\render-proof|Number of Roots Between>
      \ Computes the number of real roots of a polynomial between two real
      numbers

      <\unfolded>
        Syntax
      <|unfolded>
        Name : numberOfRootsBetween(P,var,a,b)

        Input : P polynomial

        \ \ \ \ \ \ \ \ \ \ var is the variable of the polynomial (for
        example x)

        \ \ \ \ \ \ \ \ \ \ a and b are reals (a\<less\>b) or -INFINITY or
        +INFINITY

        Method :\ 

        <\enumerate-roman>
          <item>sRem [signed remainder sequence]

          <item>sSubRes [signed subresultants]

          <item>deCasteljau [De Casteljau method for isolation]*

          <item><with|color|grey|monomial [monomial method for isolation]>
        </enumerate-roman>

        \;

        Output : number of roots of P in the interval ]a,b[
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>8)
            <with|color|black|>>
          <|unfolded-io>
            numberOfRootsBetween(x^2-2,x,0,10);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o8>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>9)
            <with|color|black|>>
          <|unfolded-io>
            deCasteljauNumberOfRootsBetween(x^2-2,x,0,10);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o9>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>10)
            <with|color|black|>>
          <|unfolded-io>
            sSubResNumberOfRootsBetween(x^2-2,x,0,10);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o10>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>11)
            <with|color|black|>>
          <|unfolded-io>
            sRemNumberOfRootsBetween(x^2-2,x,0,10);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o11>)
            <with|color|black|>>1>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>12)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Hankel Matrix|Computes the Hankel quadratic form associated
    to a sequence of numbers>
  <|detailed>
    <\render-proof|Hankel Matrix>
      \ Computes the Hankel quadratic form associated to a sequence of
      numbers

      <\unfolded>
        Syntax
      <|unfolded>
        Name : hankelMatrix(seq)

        Input : sequence seq of odd length of elements of an integral domain

        Output : Hankel quadratic form for seq (represented by a square
        symmetric matrix)
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>119)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o119>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>120)
            <with|color|black|>>
          <|unfolded-io>
            hankelMatrix([0,1,2,3,4]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o120>)
            <with|color|black|>><left|[><left|[>0,1,2<right|]>,<left|[>1,2,3<right|]>,<left|[>2,3,4<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>121)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Hankel Signature|Computes the signature of the Hankel
    quadratic form associated to a sequence >
  <|detailed>
    <\render-proof|Hankel Signature>
      \ Computes the signature of the Hankel quadratic form associated to a
      sequence\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : hankelSignature(seq)

        Input : sequence seq of odd length of elements of an integral domain

        Output : signature of the Hankel quadratic form for seq
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>117)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o117>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>118)
            <with|color|black|>>
          <|unfolded-io>
            hankelSignature([0,1,2,3,4]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o118>)
            <with|color|black|>>0>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>119)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>1)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o1>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Difference of positive and negative real part of
    roots|Computes the difference between the number of roots a polynomail
    with positive real part and those with negative real part>
  <|detailed>
    <\render-proof|Difference of positive and negative roots>
      \ Computes the difference between the number of roots a polynomail with
      positive real part and those with negative real part

      <\unfolded>
        Syntax
      <|unfolded>
        Name : posNegDiff(P,var)

        Input : P is a polynomial in variable var

        Output : difference between the number of roots of P with positive
        real part and those with negative real part
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>114)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o114>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>115)
            <with|color|black|>>
          <|unfolded-io>
            posNegDiff((x^2-1)*(x^3-1),x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o115>)
            <with|color|black|>>-1>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>116)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootCounting.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsubsection|Isolation of roots>

  The corresponding results are explained in Chapter 10 of "Algorithms in
  Real Algebraic Geometry" by S. Basu, R. Pollack, M.-F. Roy

  \;

  <em|file : rootIsolation.mac>

  The routines contained in this files deal with the problem of isolation of
  real roots by using the conversion to the Bernstein basis and De
  Casteljau's method.

  <samp|<strong|<samp|<strong|Auxiliary Functions :
  ><samp|>><strong|<verbatim|<em|<em|>>>>>>

  <\detailed>
    <render-proof|Cauchy Upper Bound|Computes the upper bound for the
    absolute values of all real roots of a polynomial>
  <|detailed>
    <\render-proof|Cauchy Upper Bound>
      \ Computes the difference between the number of roots a polynomail with
      positive real part and those with negative real part

      <\unfolded>
        Syntax
      <|unfolded>
        Name : cauchyRootUpperBound(P,var)

        Input : P is a polynomial in variable var

        Output : the upper bound for the absolute values of all real roots of
        P
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>7)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o7>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>8)
            <with|color|black|>>
          <|unfolded-io>
            cauchyRootUpperBound(x+2,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o8>)
            <with|color|black|>>3>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>9)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Cauchy Lower Bound|Computes the lower bound for the
    absolute values of all real roots of a polynomial >
  <|detailed>
    <\render-proof|Cauchy Lower Bound>
      \ Computes the lower bound for the absolute values of all real roots of
      a polynomial\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : cauchyRootLowerBound(P,var)

        Input : P is a polynomial in variable var

        Output : the lower bound for the absolute values of all non-zero real
        roots of P
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>9)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o9>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>10)
            <with|color|black|>>
          <|unfolded-io>
            cauchyRootLowerBound(x+2,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o10>)
            <with|color|black|>><frac|2|3>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>11)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Prime Cauchy Upper Bound|Computes (alternative) upper bound
    for the absolute values of all real roots of a polynomial >
  <|detailed>
    <\render-proof|Prime Cauchy Upper Bound>
      Computes an (alternative) upper bound for the absolute values of all
      real roots of a polynomial \ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : primeCauchyRootUpperBound(P,var)

        Input : P is a polynomial in variable var

        Output : (alternative) upper bound for the absolute values of all
        real roots of P
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>3)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o3>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>45)
            <with|color|black|>>
          <|unfolded-io>
            primeCauchyRootUpperBound(x+2,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o45>)
            <with|color|black|>>10>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>46)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Prime Cauchy Lower Bound|Computes an (alternative) lower
    bound for the absolute values of all real roots of a polynomial P>
  <|detailed>
    <\render-proof|Prime Cauchy Lower Bound>
      \ Computes an (alternative) lower bound for the absolute values of all
      real roots of a polynomial P

      <\unfolded>
        Syntax
      <|unfolded>
        Name : primeCauchyRootLowerBound(P,var)

        Input : P is a polynomial in variable var

        Output : (alternative) lower bound for the absolute values of all
        non-zero real roots of P
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>11)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o11>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>12)
            <with|color|black|>>
          <|unfolded-io>
            primeCauchyRootLowerBound(x+2,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o12>)
            <with|color|black|>><frac|2|5>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>13)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Convert to Bernstein|Computes the coefficients of a
    polynomial in the Berstein's Basis>
  <|detailed>
    <\render-proof|Convert to Berstein>
      \ Computes the coefficients of a polynomial in the Berstein's Basis

      <\unfolded>
        Syntax
      <|unfolded>
        Name : convert2Bernstein(P,d,var,l,r)

        Input : P is a polynomial in variable var of degree at most d.

        \ \ \ \ \ \ \ \ \ \ l and r are the parameters of the Basis.
        (l\<less\>r)

        Output : list containing the coefficients of P in the Bernstein basis
        of degree d for l,r
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>13)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o13>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>14)
            <with|color|black|>>
          <|unfolded-io>
            convert2Bernstein(x^2,2,x,0,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o14>)
            <with|color|black|>><left|[>0,0,1<right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>15)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Berstein Split|Computes the coefficients of P in the
    Berstein's Basis for l,m and mr, knowing those for l,r>
  <|detailed>
    <\render-proof|Berntein Split>
      Computes the coefficients of P in the Berstein's Basis for l,m and mr,
      knowing those for l,r

      <\unfolded>
        Syntax
      <|unfolded>
        Name : bernsteinSplit(coeffList, l,r,m)

        Input : coeffList is the list of coefficients of a polynomial in
        Berstein basis for l,r, m is another number

        Output : [bern_lm, bern_mr] where\ 

        <\enumerate-numeric>
          <item>bern_lm is a list containing the coefficients in the
          Bernstein basis of degree d for l,m

          <item>bern_mr is a list containing the coefficients in the
          Bernstein basis of degree d for m,r
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>19)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o19>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>20)
            <with|color|black|>>
          <|unfolded-io>
            bernsteinSplit([4,-6,7,10],0,1/2,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o20>)
            <with|color|black|>><left|[><left|[>4,-16,56,-44<right|]>,<left|[>-44,6,13,10<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>21)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Special Berstein Split|Computes integer multiples of the
    coefficients of P in the Berstein's Basis for l,(l+r)/2 and (l+r)/2,r
    knowing those for l,r>
  <|detailed>
    <\render-proof|Special Berntein Split>
      \ Computes integer multiples of the coefficients of P in the Berstein's
      Basis for l,(l+r)/2 and (l+r)/2,r knowing those for l,r

      <\unfolded>
        Syntax
      <|unfolded>
        Name : specialBernsteinSplit(coeffList, l,r)

        Input : coeffList is the list of coefficients of a polynomial in
        berstein basis for parameters l,r

        Output : [bern_first,bern_second] where :\ 

        <\enumerate-numeric>
          <item>bern_first is a list containing the coefficients in the
          Bernstein basis for l,(l+r)/2 of 2^deg(P) P

          <item>bern_second is a list containing the coefficients in the
          Bernstein basis for (l+r)/2,r of 2^deg(P) P
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <output|>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>7)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o7>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>51)
            <with|color|black|>>
          <|unfolded-io>
            specialBernsteinSplit([4,-6,7,10],0,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o51>)
            <with|color|black|>><left|[><left|[>32,-8,-2,17<right|]>,<left|[>17,36,68,80<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>52)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <samp|<strong|<samp|<strong|Main Functions :
  ><samp|>><strong|<verbatim|<em|<em|>>>>>>

  <\detailed>
    <render-proof|Isolate Roots|Computes a list containing points or open
    intervals which contain the roots of a given polynomial>
  <|detailed>
    <\render-proof|Isolate Roots>
      \ Computes a list containing points or open intervals which contain the
      roots of a given polynomial

      <\unfolded>
        Syntax
      <|unfolded>
        Name : isolateRoots(P,var)

        Input : P is a polynomial in variable var.

        Method :\ 

        <\enumerate-roman>
          <item>deCasteljau [De Casteljau method for root isolation]

          <item><with|color|grey|monomial [root isolation in the monomial
          basis]>
        </enumerate-roman>

        Output : characterization of the roots of P by a list of elements of
        the form either

        <\enumerate-numeric>
          <item>[pt] describing a real root pt of P

          <item>[a,b] describing the open interval "]a,b[" containing exactly
          one root of P
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>4)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>5)
            <with|color|black|>>
          <|unfolded-io>
            isolateRoots(-33*x^3+69*x^2-30*x+4,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o5>)
            <with|color|black|>><left|[><left|[>1,2<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>6)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Isolate Roots Between|Computes a list containing points or
    open intervals which contain the roots of a given polynomial between two
    real numbers>
  <|detailed>
    <\render-proof|Isolate Roots Between>
      Computes a list containing points or open intervals which contain the
      roots of a given polynomial between two real numbers\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : isolateRootsBetween(P,var,a,b)

        Input : P is a polynomial in variable var.

        \ \ \ \ \ \ \ \ \ \ a,b two real numbers

        Method :\ 

        <\enumerate-roman>
          <item>deCasteljau [De Casteljau method for root isolation]

          <item><with|color|grey|monomial [root isolation in the monomial
          basis]>
        </enumerate-roman>

        Output : list of elements of the form either

        <\enumerate-numeric>
          <item>[pt] describing the real root pt which is a root of P

          <item>[c,d] describing the open interval "]c,d["containing exactly
          a root of P
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>16)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o16>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>17)
            <with|color|black|>>
          <|unfolded-io>
            isolateRootsBetween((x-2)^2-1,x,-4,4);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o17>)
            <with|color|black|>><left|[><left|[>0,2<right|]>,<left|[>2,4<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>18)
            <with|color|black|>>
          <|input>
            \;
          </input>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>18)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Find Roots|Computes a list containing points of open
    intervals smaller than treshold which contain exactly one root of a given
    polynomial>
  <|detailed>
    <\render-proof|Find Roots>
      \ Computes a list containing points of open intervals smaller than
      treshold which contain exactly one root of a given polynomial

      <\unfolded>
        Syntax
      <|unfolded>
        Name : findRoots(P,var,threshold)

        Input : P is a polynomial in variable var.

        \ \ \ \ \ \ \ \ \ \ threshold is a number\ 

        Method :\ 

        <\enumerate-roman>
          <item>deCasteljau [De Casteljau method for root isolation]

          <item><with|color|grey|monomial [root isolation in the monomial
          basis]>
        </enumerate-roman>

        Output : list of elements of the form either

        <\enumerate-numeric>
          <item>[pt] describing the real root pt of P

          <item>[a,b] describing the open interval "]a,b[" with b-a smaller
          than threshold containing exactly one root of P
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>25)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o25>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>26)
            <with|color|black|>>
          <|unfolded-io>
            findRoots(x+2,x,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o26>)
            <with|color|black|>><left|[><left|[>-2<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>27)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Find Roots Between|Computes a list containing open
    intervals smaller than treshold which contains at least one root of a
    given polynomial P>
  <|detailed>
    <\render-proof|Find Roots Between>
      \ Computes a list containing points of open intervals smaller than
      treshold which contain exactly one root of a given polynomial and are
      between two real numbers

      <\unfolded>
        Syntax
      <|unfolded>
        Name : findRoots(P,var,treshold)

        Input : P is a polynomial in variable var.

        \ \ \ \ \ \ \ \ \ \ treshold is the interval in which the function
        search the roots.

        Method :\ 

        <\enumerate-roman>
          <item>deCasteljau [De Casteljau method for root isolation]

          <item><with|color|grey|monomial [root isolation in the monomial
          basis]>
        </enumerate-roman>

        Output : list of elements of the form either

        <\enumerate-numeric>
          <item>[pt] describing the real root pt of P

          <item>[a,b] describing the open interval "]a,b[" smaller than
          treshold and containing exactly a root of P
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>27)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o27>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>28)
            <with|color|black|>>
          <|unfolded-io>
            findRootsBetween(x^3-1,x,1,-2,2);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o28>)
            <with|color|black|>><left|[><left|[>1<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>29)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Roots Sign|Computes a list containing couples describing
    the real roots of P and the sign of Q at these real roots>
  <|detailed>
    <\render-proof|Roots Sign>
      \ Computes a list containing couples describing the real roots of P and
      the sign of Q at these real roots

      <\unfolded>
        Syntax
      <|unfolded>
        Name : signsAtRoots(isInt,P,Q,var)

        Input : P,Q are polynomials in variable var.

        \ \ \ \ \ \ \ \ \ \ isolating list isInt for the real roots of P in
        the same form as in the output of "isolateRealRoots"

        Method :\ 

        <\enumerate-roman>
          <item>deCasteljau [De Casteljau method for root isolation]

          <item><with|color|grey|monomial [root isolation in the monomial
          basis]>
        </enumerate-roman>

        Output : lists of couples describing a real root and the sign of Q at
        this real root
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>29)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o29>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>30)
            <with|color|black|>>
          <|unfolded-io>
            polR:(x-2)*(x^2-1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o30>)
            <with|color|black|>><left|(>x-2<right|)>*<left|(>x<rsup|2>-1<right|)>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>31)
            <with|color|black|>>
          <|unfolded-io>
            isInt : deCasteljauIsolateRoots(polR,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o31>)
            <with|color|black|>><left|[><left|[>-8,0<right|]>,<left|[>0,2<right|]>,<left|[>2<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>32)
            <with|color|black|>>
          <|unfolded-io>
            polQ:x^2-4;
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o32>)
            <with|color|black|>>x<rsup|2>-4>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>37)
            <with|color|black|>>
          <|unfolded-io>
            signsAtRoots(isInt,polR,polQ,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o37>)
            <with|color|black|>><left|[><left|[><left|[>-2,0<right|]>,-1<right|]>,<left|[><left|[>0,2<right|]>,-1<right|]>,<left|[><left|[>2<right|]>,0<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>36)
            <with|color|black|>>
          <|unfolded-io>
            deCasteljauSignsAtRoots(isInt,polR,polQ,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o36>)
            <with|color|black|>><left|[><left|[><left|[>-2,0<right|]>,-1<right|]>,<left|[><left|[>0,2<right|]>,-1<right|]>,<left|[><left|[>2<right|]>,0<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>37)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Compare Roots|Compares \ the roots of two polynomials>
  <|detailed>
    <\render-proof|Evaluate signs>
      \ Evaluates the signs of two polynomials at their roots

      <\unfolded>
        Syntax
      <|unfolded>
        Name : evaluateSignsAtRoots(P,Q,var)

        Input : P,Q are polynomials in variable var.

        \ \ \ \ \ \ \ \ \ \ 

        Method :\ 

        <\enumerate-roman>
          <item>deCasteljau [De Casteljau method for root isolation]

          <item><with|color|grey|monomial [root isolation in the monomial
          basis]>
        </enumerate-roman>

        Output : [com,signNComP,signNComQ] where

        <\enumerate-numeric>
          <item>com is an isolating list for the common real roots of P and Q

          <item>signNComP is an isolating list with signs of Q for the real
          roots of P that are not roots of Q

          <item>signNComQ is an isolating list with signs of P for the real
          roots of Q that are not roots of P
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>48)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o48>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>49)
            <with|color|black|>>
          <|unfolded-io>
            evaluateSignsAtRoots(x+1,x,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o49>)
            <with|color|black|>><left|[><left|[><right|]>,<left|[><left|[><left|[>-2,0<right|]>,-1<right|]><right|]>,<left|[><left|[><left|[>-1,1<right|]>,1<right|]><right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>50)
            <with|color|black|>>
          <|unfolded-io>
            deCasteljauEvaluateSignsAtRoots(x+1,x,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o50>)
            <with|color|black|>><left|[><left|[><right|]>,<left|[><left|[><left|[>-2,0<right|]>,-1<right|]><right|]>,<left|[><left|[><left|[>-1,1<right|]>,1<right|]><right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>51)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/rootIsolation.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsubsection|Sign Determination>

  The corresponding results are explained in Chapter 10 of "Algorithms in
  Real Algebraic Geometry" by S. Basu, R. Pollack, M.-F. Roy

  \;

  <em|file : signDetermination.mac>

  NOTE: When we refer to an algorithm that computes the Tarski query of
  polynomials we assume that it has the same input/output format as
  "tarskiQuery" (ses Section Root Counting)

  <\detailed>
    <render-proof|Sign Determination|Computes the signs of list of
    polynomials in a given finite set (typically defined as the zero set of a
    polynomial)>
  <|detailed>
    <\render-proof|Sign Determination>
      \ Computes the signs of list of polynomials in a given finite set
      (typically defined as the zero set of a polynomial)

      <\unfolded>
        Syntax
      <|unfolded>
        Name : signDetermination(polList,ptSet,sqAlg,var)

        Input : list polList of polynomials in var, a description of a finite
        set of points, an algorithm sqAlg to compute the Tarski query of
        polynomials in polList with respect to ptSet

        Method :\ 

        <\enumerate-roman>
          <item>naive [brute force method on a huge matrix of signs]

          <item>smart [a method that uses much smaller matrices of signs]*
        </enumerate-roman>

        \ \ \ \ \ \ 

        Output : a list representing a subset of the all elements of
        {0,-1,1}^polList describing the possible signs of the polynomials in
        polList at ptSet
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>134)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o134>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>51)
            <with|color|black|>>
          <|unfolded-io>
            signDetermination( [x,x+1,x-2], x^5-9*x^3-x^2+9, tarskiQuery,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o51>)
            <with|color|black|>><left|[><left|[>1,1,1<right|]>,<left|[>1,1,-1<right|]>,<left|[>-1,-1,-1<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>52)
            <with|color|black|>>
          <|unfolded-io>
            smartSignDetermination( [x,x+1,x-2], x^5-9*x^3-x^2+9,
            tarskiQuery,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o52>)
            <with|color|black|>><left|[><left|[>1,1,1<right|]>,<left|[>1,1,-1<right|]>,<left|[>-1,-1,-1<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>53)
            <with|color|black|>>
          <|unfolded-io>
            naiveSignDetermination( [x,x+1,x-2], x^5-9*x^3-x^2+9,
            tarskiQuery,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o53>)
            <with|color|black|>><left|[><left|[>-1,-1,-1<right|]>,<left|[>1,1,-1<right|]>,<left|[>1,1,1<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>54)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/signDetermination.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsubsection|Thom encoding>

  The corresponding results are explained in Chapter 10 of "Algorithms in
  Real Algebraic Geometry" by S. Basu, R. Pollack, M.-F. Roy

  <em|file : signDetermination.mac>

  <\detailed>
    <render-proof|Thom Encoding|Computes the Thom encodings of the real roots
    of a polynomial, which is the list of signs taken by the derivatives>
  <|detailed>
    <\render-proof|Thom Encoding>
      \ Computes the Thom encodings of the real roots of a polynomial, which
      is the list of signs taken by the derivatives

      <\unfolded>
        Syntax
      <|unfolded>
        Name : thomEncoding(P,var)

        Input : polynomial P in variable var\ 

        Output : a list containing the Thom encoding of the real roots of P
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>54)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o54>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>56)
            <with|color|black|>>
          <|unfolded-io>
            thomEncoding(x^2-2,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o56>)
            <with|color|black|>><left|[><left|[>-1,1<right|]>,<left|[>1,1<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>57)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/signDetermination.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Thom Compare |Compares the Thom encodings of two
    polynomials>
  <|detailed>
    <\render-proof|Thom Compare>
      \ Compares the Thom encodings of the real roots of two polynomials

      <\unfolded>
        Syntax
      <|unfolded>
        Name : thomCompare(P,Q,var)

        Input : polynomials P,Q in variable var

        Output : a list containing elements of the form [owner,thomInf] with
        the following possibilities :\ 

        <\enumerate-numeric>
          <item>[0,thomP,thomQ] for a common root of P with Thom encoding
          thomP and of Q with Thom encoding thomQ

          <item>[1,thomP] for a root of P not of Q with Thom encoding thomP

          <item>[2,thomQ] for a root of Q not of P with Thom encoding thomQ
        </enumerate-numeric>

        Moreover the corresponding real numbers are ordered.
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>55)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o55>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>133)
            <with|color|black|>>
          <|unfolded-io>
            thomCompare( x^2-4, expand((x-2)*(x^3-1)),x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o133>)
            <with|color|black|>><left|[><left|[>1,<left|[>-1,1<right|]><right|]>,<left|[>2,<left|[>-1,0,1,1<right|]><right|]>,<left|[>0,<left|[>1,1<right|]>,<left|[>1,1,1,1<right|]><right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>134)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/signDetermination.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Thom Signs at Roots |Computes the Thom encoding of P at
    each root and the sign of Q for each root>
  <|detailed>
    <\render-proof|Thom Encoding with signs>
      Computes the Thom encoding of P at each root and the sign of Q for each
      root\ 

      <\unfolded>
        Syntax
      <|unfolded>
        Name : thomEncodingWithSigns(P,Q,var)

        Input : polynomials P,Q in variable var

        Output : a list of couples containing for each root of P its Thom
        encodings and the corresponding sign of Q
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>57)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o57>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>58)
            <with|color|black|>>
          <|unfolded-io>
            thomEncodingWithSigns(x^2-2,x-1,x);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o58>)
            <with|color|black|>><left|[><left|[><left|[>1,1<right|]>,1<right|]>,<left|[><left|[>-1,1<right|]>,-1<right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>59)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/signDetermination.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io|<with|color|red|(<with|math-font-family|rm|%i>4)
          <with|color|black|>>>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\input|<with|color|red|(<with|math-font-family|rm|%i>5)
          <with|color|black|>>>
            \;
          </input>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsection|Topology>

  The corresponding results are explained in Chapter 11 of "Algorithms in
  Real Algebraic Geometry" by S. Basu, R. Pollack, M.-F. Roy

  <\detailed>
    <render-proof|Topology:| Computes the topology of a plane curve>
  <|detailed>
    <\render-proof|Topology:>
      \ Computes the topology of a plane curve

      <\unfolded>
        Syntax
      <|unfolded>
        Name: topology(curve,x,y).

        Input: the equation of a curve in two variables with rational
        coefficients and the name of the two variables.

        Output: a couple whose first element gives the value of
        <with|mode|math|a> in the initial change of coordinates, the second
        describes the topology with respect to the new coordinates. It gives
        for each interval between the roots of the discriminant the number of
        branches above it and for each root <with|mode|math|x> of the
        discriminant, a couple containing the number of points of the curve
        above <with|mode|math|x> and the position of the unique critical
        point over <with|mode|math|x>.

        More precisely, the output is <with|mode|math|[a,<left|[>m<rsub|0>,<left|[>n<rsub|1>,c<rsub|1><right|]>,\<ldots\>,m<rsub|r-1>,<left|[>n<rsub|r>,c<rsub|r><right|]>,m<rsub|r><right|]><right|]>.>

        \;

        Name: drawTopology(T[2],x,y).

        Input: the output T to tolology(curve,x,y).

        Output: a piecewise linear curve homeomorpic to the zero set of the
        polynomial curve.
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>1)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o1>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>2)
            <with|color|black|>>
          <|unfolded-io>
            examplecurve:2*y^3+(3*x-3)*y^2+(3*x^2-3*x)*y+x^3;
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o2>)
            <with|color|black|>>2*y<rsup|3>+<left|(>3*x-3<right|)>*y<rsup|2>+<left|(>3*x<rsup|2>-3*x<right|)>*y+x<rsup|3>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>3)
            <with|color|black|>>
          <|unfolded-io>
            T:topology(examplecurve,x,y);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o3>)
            <with|color|black|>><left|[>0,<left|[>1,<left|[>2,2<right|]>,3,<left|[>2,1<right|]>,3,<left|[>2,2<right|]>,1<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>4)
            <with|color|black|>>
          <|unfolded-io>
            drawTopology(T[2]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o4>)
            <with|color|black|>><with|math-font-family|bf|true>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>5)
            <with|color|black|>>
          <|unfolded-io>
            vide:topology(x^2+y^2+1,x,y);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o5>)
            <with|color|black|>><left|[>0,<left|[>0<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>6)
            <with|color|black|>>
          <|unfolded-io>
            drawTopology(vide[2]);
          <|unfolded-io>
            plot2d: nothing to plot.

            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o6>)
            <with|color|black|>><with|math-font-family|bf|true>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>7)
            <with|color|black|>>
          <|unfolded-io>
            notgeneric:(y^2+x)*(y^2-x+1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o7>)
            <with|color|black|>><left|(>y<rsup|2>-x+1<right|)>*<left|(>y<rsup|2>+x<right|)>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>8)
            <with|color|black|>>
          <|unfolded-io>
            B:topology(notgeneric,x,y);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o8>)
            <with|color|black|>><left|[>1,<left|[>2,<left|[>1,1<right|]>,0,<left|[>1,1<right|]>,2<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>9)
            <with|color|black|>>
          <|unfolded-io>
            drawTopology(B[2]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o9>)
            <with|color|black|>><with|math-font-family|bf|true>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>10)
            <with|color|black|>>
          <|input>
            \;
          </input>
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/topology.mac> <with|font-family|tt|>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>70)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o70>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <subsection|Certificate of positivity>

  a) In the univariate case, the corresponding reference is F. Boudaoud, F.
  Caruso M.-F. Roy Certificates of positivity in the Bernstein basis,
  Discrete and Computational Geometry 39 4 639-655 (2008)

  <em|file : certificateOfPositivity.mac>

  <\detailed>
    <render-proof|Certificate|Decides whether a polynomial is positive or
    negative on an interval and provides a certificate>
  <|detailed>
    <\render-proof|Certificate of positivity>
      \ Decides whether a polynomial is positive or negative on an interval
      and provides a certificate

      <\unfolded>
        Syntax
      <|unfolded>
        Name : certificate(P,var,a,b)

        Input : P is a polynomial in variable var. a and b are real numbers

        Output :\ 

        <\enumerate-numeric>
          <item>[positive, certificate] if P is positive. Certificate\ 

          <item>[negative, certificate] if P is negative

          <item>[false, [a], sqPol] if P(a) equal 0 (where sqPol is the
          separable part of P)

          <item>[false, [c,d], sqPol] if sqPol(c)*sqPol(d)\<less\>0 (where
          sqPol is the separable part of P)
        </enumerate-numeric>
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>10)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o10>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>11)
            <with|color|black|>>
          <|unfolded-io>
            certificate(x^4+(8*x-1)^2,x,-1,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o11>)
            <with|color|black|>><left|[><with|math-font-family|rm|positive>,<left|[><left|[><left|[>-1,0<right|]>,3,<left|[>3936,2160,944,240,48<right|]><right|]>,<left|[><left|[>0,<frac|1|8><right|]>,3,<left|[>196608,98304,32768,0,48<right|]><right|]>,<left|[><left|[><frac|1|8>,1<right|]>,3,<left|[>48,384,1608704,4841472,9830400<right|]><right|]><right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>29)
            <with|color|black|>>
          <|unfolded-io>
            certificate((x-2)^2-1,x,-1,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o29>)
            <with|color|black|>><left|[><with|math-font-family|bf|false>,<left|[><left|[>1<right|]>,x<rsup|2>-4*x+3<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>30)
            <with|color|black|>>
          <|unfolded-io>
            certificate((2*x^2-1)^2,x,-1,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o30>)
            <with|color|black|>><left|[><with|math-font-family|bf|false>,<left|[>-1,0<right|]>,4*x<rsup|2>-2<right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>31)
            <with|color|black|>>
          <|unfolded-io>
            certificate(-x^4-(8*x-1)^2,x,-1,1);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o31>)
            <with|color|black|>><left|[><with|math-font-family|rm|negative>,<left|[><left|[><left|[>-1,0<right|]>,3,<left|[>-3936,-2160,-944,-240,-48<right|]><right|]>,<left|[><left|[>0,<frac|1|8><right|]>,3,<left|[>-196608,-98304,-32768,0,-48<right|]><right|]>,<left|[><left|[><frac|1|8>,1<right|]>,3,<left|[>-48,-384,-1608704,-4841472,-9830400<right|]><right|]><right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>32)
            <with|color|black|>>
          <|input>
            \;
          </input>

          \;
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/certificateOfPositivity.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>6)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o6>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>
        </session>
      </folded>
    </render-proof>
  </detailed>

  b) In the multivariate case, the corresponding reference is R. Leroy,
  Certificats de positivit et minimisation polynomiale dans la base de
  Bernstein multivarie \ http://tel.archives-ouvertes.fr/tel-00349444/fr/

  <em|file : multiCertificateOfPositivity.mac>

  <\detailed>
    <render-proof|Bernstein coefficients on a simplex|Various annex functions
    expressing a polynomial in the Bernstein basis on a simplex.>
  <|detailed>
    <\render-proof|Bernstein coefficients on a simplex>
      \ Various annex functions expressing a polynomial in the Bernstein
      basis on a simplex.

      <\unfolded>
        Syntax
      <|unfolded>
        Name : compositions(d,k+1)

        Input : d and k are natural numbers

        Output : all the multiindices of sum d and length k+1

        \;

        Name : simplex2bar(V,vars)

        Input : a simplex V given by k+1 points, each of them described by
        its k coordinates

        Output : the k+1 barycentric coordinates definining the simplex

        \;

        Name : monom2bern(P,V,vars,d)

        Input : P is a multivariate polynomial in a list of k variable vars,
        d is at least the degree of P, V is a simplex described by k+1 points
        with k coordinate

        Output : the list of coefficients of P in the Bernstein basis \ of
        degree d on V(in the order corresponding to compositions d,k for the
        barycentric coordinates given by simplex2bar)

        \;

        Name : deCasteljau(simpl,ber,deg,M)

        Input : a simplex defined by k+1 points with k coordinates, Bernstein
        coefficients on this simplex of a polynomial of degree at most deg
        and the k coordinates of a point

        Output : the list of coefficients of P in the Bernstein basis \ of
        degree d on the k+1 subsimplices defined by the initial simplex and
        the point

        \;
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>30)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o30>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>31)
            <with|color|black|>>
          <|unfolded-io>
            Comp:compositions(2,3);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o31>)
            <with|color|black|>><left|[><left|[>2,0,0<right|]>,<left|[>1,1,0<right|]>,<left|[>1,0,1<right|]>,<left|[>0,2,0<right|]>,<left|[>0,1,1<right|]>,<left|[>0,0,2<right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>32)
            <with|color|black|>>
          <|unfolded-io>
            L:simplex2bar([[0,0],[1,0],[0,1]],[x,y]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o32>)
            <with|color|black|>><left|[>-y-x+1,x,y<right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>33)
            <with|color|black|>>
          <|unfolded-io>
            expand(sum(apply(multinomial_coeff,Comp[i])*prod(L[j]^Comp[i][j],j,1,length(L)),i,1,length(Comp)));:monom2bern(9*y^2-
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o33>)
            <with|color|black|>>1>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>35)
            <with|color|black|>>
          <|unfolded-io>
            B:monom2bern(9*y^2-24*x*y+12*y+16*x^2+16*x+5,[[0,0],[1,0],[0,1]],[x,y],2);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o35>)
            <with|color|black|>><left|[>5,13,11,37,7,26<right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>36)
            <with|color|black|>>
          <|unfolded-io>
            expand(sum(B[i]*apply(multinomial_coeff,Comp[i])*prod(L[j]^Comp[i][j],j,1,length(L)),i,1,length(Comp)));:monom2bern(9*y^2-;
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o36>)
            <with|color|black|>>9*y<rsup|2>-24*x*y+12*y+16*x<rsup|2>+16*x+5>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>38)
            <with|color|black|>>
          <|unfolded-io>
            deCasteljau([[0,0],[1,0],[0,1]],B,2,[1/2,1/2]);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o38>)
            <with|color|black|>><left|[><left|[><left|[><left|[><frac|1|2>,<frac|1|2><right|]>,<left|[>1,0<right|]>,<left|[>0,1<right|]><right|]>,<left|[><frac|77|4>,22,<frac|33|2>,37,7,26<right|]><right|]>,<left|[><left|[><left|[>0,0<right|]>,<left|[><frac|1|2>,<frac|1|2><right|]>,<left|[>0,1<right|]><right|]>,<left|[>5,12,11,<frac|77|4>,<frac|33|2>,26<right|]><right|]>,<left|[><left|[><left|[>0,0<right|]>,<left|[>1,0<right|]>,<left|[><frac|1|2>,<frac|1|2><right|]><right|]>,<left|[>5,13,12,37,22,<frac|77|4><right|]><right|]><right|]>>
          </unfolded-io>

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>39)
            <with|color|black|>>
          <|input>
            \;
          </input>

          \;
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/multiCertificateOfPositivity.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>38)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o38>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>
        </session>
      </folded>
    </render-proof>
  </detailed>

  <\detailed>
    <render-proof|Bernstein coefficients in the multivariate case|Various
    functions related to the expression of a multivariate polynomial in the
    Bernstein basis>
  <|detailed>
    <\render-proof|Certificate of positivity in the multivariate case>
      \ Decides whether a polynomial is positive \ on a simplex and provides
      a certificate

      <\unfolded>
        Syntax
      <|unfolded>
        Name : multiCertificate(P,V,vars,d,sub,cert)

        Input : P is a multivariate polynomial in a list of k variable vars,
        d is at least the degree of P, V is a simplex described by k+1 points
        with k coordinates, sub is a subdivision method (bisection,
        bisection_castel, standard_triang2, bisection_max_pos)

        Output :\ 

        <\enumerate-numeric>
          <item>[certificate] if P is positive i.e. a sequence of
          subsimplexes and Bernstein coefficients on the corresponding
          subsimplex

          <item>[a, sign(P(a))] if P(a)<with|mode|math|\<leqslant\>>0\ 

          <item>in other cases the output is not satisfactory yet
        </enumerate-numeric>

        Name : drawMultiCertificate(list)

        Input : the certficate output by multiCertificate, when the
        polynomial is positive, in the bivariate case

        Output : a picture of the corresponding subdivision
      </unfolded>

      <\unfolded>
        Example
      <|unfolded>
        <\session|maxima|default>
          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>39)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o39>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>40)
            <with|color|black|>>
          <|unfolded-io>
            f:9*y^2-24*x*y+12*y+16*x^2-16*x+5;
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o40>)
            <with|color|black|>>9*y<rsup|2>-24*x*y+12*y+16*x<rsup|2>-16*x+5>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>41)
            <with|color|black|>>
          <|unfolded-io>
            C1:multiCertificate(f,[[0,0],[1,0],[0,1]],[x,y],2,bisection,pos);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o41>)
            <with|color|black|>><left|[><left|[><left|[><left|[>0,0<right|]>,<left|[><frac|1|2>,<frac|1|2><right|]>,<left|[>0,1<right|]><right|]>,<left|[>5,4,11,<frac|13|4>,<frac|17|2>,26<right|]><right|]>,<left|[><left|[><left|[>0,0<right|]>,<left|[><frac|1|2>,0<right|]>,<left|[><frac|1|2>,<frac|1|2><right|]><right|]>,<left|[>5,1,4,1,1,<frac|13|4><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0<right|]>,<left|[><frac|3|4>,<frac|1|4><right|]>,<left|[><frac|1|2>,<frac|1|2><right|]><right|]>,<left|[>1,1,1,<frac|17|16>,<frac|5|8>,<frac|13|4><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0<right|]>,<left|[>1,0<right|]>,<left|[><frac|3|4>,<frac|1|4><right|]><right|]>,<left|[>1,1,1,5,<frac|3|2>,<frac|17|16><right|]><right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>42)
            <with|color|black|>>
          <|unfolded-io>
            drawMultiCertificate(C1,500);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o42>)
            <with|color|black|>><left|[><with|math-font-family|rm|gr2d><left|(><with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon><right|)><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>43)
            <with|color|black|>>
          <|unfolded-io>
            C2:multiCertificate(f,[[0,0],[1,0],[0,1]],[x,y],2,bisection_max_pos,pos);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o43>)
            <with|color|black|>><left|[><left|[><left|[><left|[>0,0<right|]>,<left|[><frac|7|10>,<frac|3|10><right|]>,<left|[>0,1<right|]><right|]>,<left|[>5,<frac|6|5>,11,<frac|101|100>,<frac|3|2>,26<right|]><right|]>,<left|[><left|[><left|[><frac|2|5>,0<right|]>,<left|[>1,0<right|]>,<left|[><frac|7|10>,<frac|3|10><right|]><right|]>,<left|[><frac|29|25>,<frac|1|5>,<frac|26|25>,5,<frac|4|5>,<frac|101|100><right|]><right|]>,<left|[><left|[><left|[>0,0<right|]>,<left|[><frac|2|5>,0<right|]>,<left|[><frac|7|10>,<frac|3|10><right|]><right|]>,<left|[>5,<frac|9|5>,<frac|6|5>,<frac|29|25>,<frac|26|25>,<frac|101|100><right|]><right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>44)
            <with|color|black|>>
          <|unfolded-io>
            drawMultiCertificate(C2,500);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o44>)
            <with|color|black|>><left|[><with|math-font-family|rm|gr2d><left|(><with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon><right|)><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>45)
            <with|color|black|>>
          <|unfolded-io>
            C3:multiCertificate(f,[[0,0],[1,0],[0,1]],[x,y],2,standard_triang2,pos);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o45>)
            <with|color|black|>><left|[><left|[><left|[><left|[>0,<frac|1|2><right|]>,<left|[><frac|1|2>,<frac|1|2><right|]>,<left|[>0,1<right|]><right|]>,<left|[><frac|53|4>,<frac|25|4>,<frac|37|2>,<frac|13|4>,<frac|17|2>,26<right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0<right|]>,<left|[>0,<frac|1|2><right|]>,<left|[><frac|1|2>,<frac|1|2><right|]><right|]>,<left|[>1,1,1,<frac|53|4>,<frac|25|4>,<frac|13|4><right|]><right|]>,<left|[><left|[><left|[>0,0<right|]>,<left|[><frac|1|2>,0<right|]>,<left|[>0,<frac|1|2><right|]><right|]>,<left|[>5,1,8,1,1,<frac|53|4><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,<frac|1|4><right|]>,<left|[><frac|3|4>,<frac|1|4><right|]>,<left|[><frac|1|2>,<frac|1|2><right|]><right|]>,<left|[><frac|25|16>,<frac|13|16>,<frac|17|8>,<frac|17|16>,<frac|5|8>,<frac|13|4><right|]><right|]>,<left|[><left|[><left|[><frac|3|4>,0<right|]>,<left|[>1,0<right|]>,<left|[><frac|3|4>,<frac|1|4><right|]><right|]>,<left|[>2,3,<frac|5|4>,5,<frac|3|2>,<frac|17|16><right|]><right|]>,<left|[><left|[><left|[><frac|3|4>,0<right|]>,<left|[><frac|1|2>,<frac|1|4><right|]>,<left|[><frac|3|4>,<frac|1|4><right|]><right|]>,<left|[>2,<frac|1|4>,<frac|5|4>,<frac|25|16>,<frac|13|16>,<frac|17|16><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0<right|]>,<left|[><frac|3|4>,0<right|]>,<left|[><frac|1|2>,<frac|1|4><right|]><right|]>,<left|[>1,1,1,2,<frac|1|4>,<frac|25|16><right|]><right|]><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>46)
            <with|color|black|>>
          <|unfolded-io>
            drawMultiCertificate(C3,500);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o46>)
            <with|color|black|>><left|[><with|math-font-family|rm|gr2d><left|(><with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon>,<with|math-font-family|rm|polygon><right|)><right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>47)
            <with|color|black|>>
          <|unfolded-io>
            multiCertificate(x^2-y^2-1,[[0,0],[1,0],[0,1]],[x,y],2,bisection,pos);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o47>)
            <with|color|black|>><left|[><left|[>0,0<right|]>,-1<right|]>>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>48)
            <with|color|black|>>
          <|unfolded-io>
            g:9*y^2-24*x*y+12*y+16*x^2-16*x+5+z^2;
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o48>)
            <with|color|black|>>z<rsup|2>+9*y<rsup|2>-24*x*y+12*y+16*x<rsup|2>-16*x+5>
          </unfolded-io>

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>49)
            <with|color|black|>>
          <|unfolded-io>
            M1:multiCertificate(g,[[0,0,0],[1,0,0],[0,1,0],[0,0,1]],[x,y,z],2,standard_triang2,pos);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o49>)
            <with|color|black|>><left|[><left|[><left|[><left|[>0,0,<frac|1|2><right|]>,<left|[><frac|1|2>,0,<frac|1|2><right|]>,<left|[>0,<frac|1|2>,<frac|1|2><right|]>,<left|[>0,0,1<right|]><right|]>,<left|[><frac|21|4>,<frac|5|4>,<frac|33|4>,<frac|11|2>,<frac|5|4>,<frac|5|4>,<frac|3|2>,<frac|27|2>,<frac|17|2>,6<right|]><right|]>,<left|[><left|[><left|[>0,<frac|1|2>,0<right|]>,<left|[><frac|1|2>,<frac|1|2>,0<right|]>,<left|[>0,1,0<right|]>,<left|[>0,<frac|1|2>,<frac|1|2><right|]><right|]>,<left|[><frac|53|4>,<frac|25|4>,<frac|37|2>,<frac|53|4>,<frac|13|4>,<frac|17|2>,<frac|25|4>,26,<frac|37|2>,<frac|27|2><right|]><right|]>,<left|[><left|[><left|[>0,<frac|1|2>,0<right|]>,<left|[><frac|1|2>,<frac|1|2>,0<right|]>,<left|[><frac|1|2>,0,<frac|1|2><right|]>,<left|[>0,<frac|1|2>,<frac|1|2><right|]><right|]>,<left|[><frac|29|4>,<frac|9|4>,6,<frac|29|4>,<frac|5|4>,2,<frac|9|4>,<frac|21|4>,<frac|25|4>,<frac|15|2><right|]><right|]>,<left|[><left|[><left|[>0,<frac|1|2>,0<right|]>,<left|[>0,0,<frac|1|2><right|]>,<left|[><frac|1|2>,0,<frac|1|2><right|]>,<left|[>0,<frac|1|2>,<frac|1|2><right|]><right|]>,<left|[><frac|29|4>,6,6,<frac|29|4>,<frac|21|4>,<frac|21|4>,<frac|25|4>,<frac|21|4>,<frac|25|4>,<frac|15|2><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0,0<right|]>,<left|[>0,<frac|1|2>,0<right|]>,<left|[><frac|1|2>,<frac|1|2>,0<right|]>,<left|[><frac|1|2>,0,<frac|1|2><right|]><right|]>,<left|[>1,1,1,1,<frac|53|4>,<frac|25|4>,1,<frac|13|4>,1,<frac|5|4><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0,0<right|]>,<left|[>0,<frac|1|2>,0<right|]>,<left|[>0,0,<frac|1|2><right|]>,<left|[><frac|1|2>,0,<frac|1|2><right|]><right|]>,<left|[>1,1,1,1,<frac|85|4>,1,1,<frac|5|4>,<frac|5|4>,<frac|5|4><right|]><right|]>,<left|[><left|[><left|[>0,0,0<right|]>,<left|[><frac|1|2>,0,0<right|]>,<left|[>0,<frac|1|2>,0<right|]>,<left|[>0,0,<frac|1|2><right|]><right|]>,<left|[>5,1,8,5,1,1,1,<frac|53|4>,8,<frac|21|4><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0,<frac|1|4><right|]>,<left|[><frac|3|4>,0,<frac|1|4><right|]>,<left|[><frac|1|2>,<frac|1|4>,<frac|1|4><right|]>,<left|[><frac|1|2>,0,<frac|1|2><right|]><right|]>,<left|[><frac|17|16>,<frac|17|16>,<frac|17|16>,<frac|9|8>,<frac|33|16>,<frac|5|16>,<frac|9|8>,<frac|13|8>,<frac|9|8>,<frac|5|4><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,<frac|1|4>,0<right|]>,<left|[><frac|3|4>,<frac|1|4>,0<right|]>,<left|[><frac|1|2>,<frac|1|2>,0<right|]>,<left|[><frac|1|2>,<frac|1|4>,<frac|1|4><right|]><right|]>,<left|[><frac|25|16>,<frac|13|16>,<frac|17|8>,<frac|25|16>,<frac|17|16>,<frac|5|8>,<frac|13|16>,<frac|13|4>,<frac|17|8>,<frac|13|8><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,<frac|1|4>,0<right|]>,<left|[><frac|3|4>,<frac|1|4>,0<right|]>,<left|[><frac|3|4>,0,<frac|1|4><right|]>,<left|[><frac|1|2>,<frac|1|4>,<frac|1|4><right|]><right|]>,<left|[><frac|5|4>,<frac|3|4>,1,<frac|5|4>,<frac|5|4>,1,<frac|3|4>,<frac|17|16>,<frac|17|16>,<frac|21|16><right|]><right|]>,<left|[><left|[><left|[><frac|3|4>,0,0<right|]>,<left|[>1,0,0<right|]>,<left|[><frac|3|4>,<frac|1|4>,0<right|]>,<left|[><frac|3|4>,0,<frac|1|4><right|]><right|]>,<left|[>2,3,<frac|5|4>,2,5,<frac|3|2>,3,<frac|17|16>,<frac|5|4>,<frac|33|16><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,<frac|1|4>,0<right|]>,<left|[><frac|1|2>,0,<frac|1|4><right|]>,<left|[><frac|3|4>,0,<frac|1|4><right|]>,<left|[><frac|1|2>,<frac|1|4>,<frac|1|4><right|]><right|]>,<left|[><frac|5|4>,1,1,<frac|5|4>,<frac|17|16>,<frac|17|16>,<frac|17|16>,<frac|17|16>,<frac|17|16>,<frac|21|16><right|]><right|]>,<left|[><left|[><left|[><frac|3|4>,0,0<right|]>,<left|[><frac|1|2>,<frac|1|4>,0<right|]>,<left|[><frac|3|4>,<frac|1|4>,0<right|]>,<left|[><frac|3|4>,0,<frac|1|4><right|]><right|]>,<left|[>2,<frac|1|4>,<frac|5|4>,2,<frac|25|16>,<frac|13|16>,<frac|1|4>,<frac|17|16>,<frac|5|4>,<frac|33|16><right|]><right|]>,<left|[><left|[><left|[><frac|3|4>,0,0<right|]>,<left|[><frac|1|2>,<frac|1|4>,0<right|]>,<left|[><frac|1|2>,0,<frac|1|4><right|]>,<left|[><frac|3|4>,0,<frac|1|4><right|]><right|]>,<left|[>2,0,2,2,2,0,0,<frac|33|16>,<frac|33|16>,<frac|33|16><right|]><right|]>,<left|[><left|[><left|[><frac|1|2>,0,0<right|]>,<left|[><frac|3|4>,0,0<right|]>,<left|[><frac|1|2>,<frac|1|4>,0<right|]>,<left|[><frac|1|2>,0,<frac|1|4><right|]><right|]>,<left|[>1,1,1,1,2,<frac|1|4>,1,<frac|25|16>,1,<frac|17|16><right|]><right|]><right|]>>
          </unfolded-io>

          \;

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>50)
            <with|color|black|>>
          <|unfolded-io>
            M2:multiCertificate(g,[[0,0,0],[1,0,0],[0,1,0],[0,0,1]],[x,y,z],2,bisection_max_pos,pos);
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o50>)
            <with|color|black|>><left|[><left|[><left|[><left|[>0,0,0<right|]>,<left|[><frac|7|10>,<frac|3|10>,0<right|]>,<left|[>0,1,0<right|]>,<left|[>0,0,1<right|]><right|]>,<left|[>5,<frac|6|5>,11,5,<frac|101|100>,<frac|3|2>,<frac|6|5>,26,11,6<right|]><right|]>,<left|[><left|[><left|[>0,0,0<right|]>,<left|[><frac|3|5>,0,<frac|2|5><right|]>,<left|[><frac|7|10>,<frac|3|10>,0<right|]>,<left|[>0,0,1<right|]><right|]>,<left|[>5,<frac|1|5>,<frac|6|5>,5,<frac|33|25>,<frac|24|25>,<frac|3|5>,<frac|101|100>,<frac|6|5>,6<right|]><right|]>,<left|[><left|[><left|[><frac|2|5>,0,0<right|]>,<left|[>1,0,0<right|]>,<left|[><frac|7|10>,<frac|3|10>,0<right|]>,<left|[><frac|3|5>,0,<frac|2|5><right|]><right|]>,<left|[><frac|29|25>,<frac|1|5>,<frac|26|25>,<frac|21|25>,5,<frac|4|5>,<frac|9|5>,<frac|101|100>,<frac|24|25>,<frac|33|25><right|]><right|]>,<left|[><left|[><left|[>0,0,0<right|]>,<left|[><frac|2|5>,0,0<right|]>,<left|[><frac|7|10>,<frac|3|10>,0<right|]>,<left|[><frac|3|5>,0,<frac|2|5><right|]><right|]>,<left|[>5,<frac|9|5>,<frac|6|5>,<frac|1|5>,<frac|29|25>,<frac|26|25>,<frac|21|25>,<frac|101|100>,<frac|24|25>,<frac|33|25><right|]><right|]><right|]>>
          </unfolded-io>

          \;

          <\input>
            <with|color|red|(<with|math-font-family|rm|%i>51)
            <with|color|black|>>
          <|input>
            \;
          </input>

          \;
        </session>
      </unfolded>

      <unfolded|Code|The code can be found in
      <with|font-family|tt|./SARAG/multiCertificateOfPositivity.mac>>

      <\folded>
        Use it yourself
      <|folded>
        <\session|maxima|default>
          \;

          <\unfolded-io>
            <with|color|red|(<with|math-font-family|rm|%i>173)
            <with|color|black|>>
          <|unfolded-io>
            load("./SARAG/sarag.mac");
          <|unfolded-io>
            <with|mode|math|math-display|true|<with|mode|text|font-family|tt|color|red|(<with|math-font-family|rm|%o173>)
            <with|color|black|>><with|mode|text|./SARAG/sarag.mac>>
          </unfolded-io>

          \;

          \;
        </session>
      </folded>
    </render-proof>
  </detailed>

  \;
</body>

<\initial>
  <\collection>
    <associate|language|french>
    <associate|magnification|1.2>
    <associate|page-orientation|landscape>
    <associate|preamble|false>
  </collection>
</initial>

<\references>
  <\collection>
    <associate|auto-1|<tuple|1|1>>
    <associate|auto-10|<tuple|2.1.1|5>>
    <associate|auto-11|<tuple|2.1.2|6>>
    <associate|auto-12|<tuple|2.1.3|8>>
    <associate|auto-13|<tuple|2.2|12>>
    <associate|auto-14|<tuple|2.2.1|12>>
    <associate|auto-15|<tuple|2.2.2|15>>
    <associate|auto-16|<tuple|2.2.3|17>>
    <associate|auto-17|<tuple|2.2.4|24>>
    <associate|auto-18|<tuple|2.2.5|35>>
    <associate|auto-19|<tuple|2.2.6|48>>
    <associate|auto-2|<tuple|1.1|1>>
    <associate|auto-20|<tuple|2.2.7|50>>
    <associate|auto-21|<tuple|2.3|53>>
    <associate|auto-22|<tuple|2.4|55>>
    <associate|auto-3|<tuple|1.2|1>>
    <associate|auto-4|<tuple|1.3|2>>
    <associate|auto-5|<tuple|1.4|3>>
    <associate|auto-6|<tuple|1.5|4>>
    <associate|auto-7|<tuple|1.6|4>>
    <associate|auto-8|<tuple|2|4>>
    <associate|auto-9|<tuple|2.1|5>>
  </collection>
</references>

<\auxiliary>
  <\collection>
    <\associate|toc>
      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|1<space|2spc>Introduction>
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-1><vspace|0.5fn>

      <with|par-left|<quote|1.5fn>|1.1<space|2spc>The SARAG Library
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-2>>

      <with|par-left|<quote|1.5fn>|1.2<space|2spc>Requirements
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-3>>

      <with|par-left|<quote|1.5fn>|1.3<space|2spc>Loading the files
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-4>>

      <with|par-left|<quote|1.5fn>|1.4<space|2spc>Manual
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-5>>

      <with|par-left|<quote|1.5fn>|1.5<space|2spc>Naming conventions
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-6>>

      <with|par-left|<quote|1.5fn>|1.6<space|2spc>Form of the output
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-7>>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|2<space|2spc>Functions
      and syntax> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-8><vspace|0.5fn>

      <with|par-left|<quote|1.5fn>|2.1<space|2spc>Linear algebra
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-9>>

      <with|par-left|<quote|3fn>|2.1.1<space|2spc>Matrix product
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-10>>

      <with|par-left|<quote|3fn>|2.1.2<space|2spc>Determinant, elimination
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-11>>

      <with|par-left|<quote|3fn>|2.1.3<space|2spc>Characteristic polynomial
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-12>>

      <with|par-left|<quote|1.5fn>|2.2<space|2spc>Root counting
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-13>>

      <with|par-left|<quote|3fn>|2.2.1<space|2spc>Signes changes
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-14>>

      <with|par-left|<quote|3fn>|2.2.2<space|2spc>Signed remainder sequence
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-15>>

      <with|par-left|<quote|3fn>|2.2.3<space|2spc>Subresultants
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-16>>

      <with|par-left|<quote|3fn>|2.2.4<space|2spc>Root counting
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-17>>

      <with|par-left|<quote|3fn>|2.2.5<space|2spc>Isolation of roots
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-18>>

      <with|par-left|<quote|3fn>|2.2.6<space|2spc>Sign Determination
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-19>>

      <with|par-left|<quote|3fn>|2.2.7<space|2spc>Thom encoding
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-20>>

      <with|par-left|<quote|1.5fn>|2.3<space|2spc>Topology
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-21>>

      <with|par-left|<quote|1.5fn>|2.4<space|2spc>Certificate of positivity
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-22>>
    </associate>
  </collection>
</auxiliary>